--sqlcmd -S <server> -d <database> -i <input file> -o <output file> -U <user> -P <password>
--sqlcmd -S <host>\<instance> -U sa -P <password> -i %userprofile%\Desktop\SchemasStatistics_MSSQL_UCMDB10.sql -v cmdb_dbname=<cmdb db> -o %userprofile%\Desktop\SchemasStatistics_MSSQL_UCMDB10_output.out -y 8000 -w 65000

set nocount on
set context_info 0x000000000000000000000001
use master

print char(13)+char(10);
SELECT Coalesce(CAST(@@VERSION as varchar(8000)), '') As "Server Information~@end";

print char(13)+char(10);

print 'ServerName~MachineName~InstanceName~ProductVersion~ProductLevel~Edition~Collation~IsClustered~IsFullTextInstalled~IsIntegratedSecurityOnly~LicenseType~NumLicenses~@end';
select /* my SchemasStatistics query */
	      Coalesce(CAST(SERVERPROPERTY('ServerName') as varchar), '')
	+'~'+ Coalesce(CAST(SERVERPROPERTY('MachineName') as varchar), '')
	+'~'+ Coalesce(CAST(SERVERPROPERTY('InstanceName') as varchar), '')
	+'~'+ Coalesce(CAST(SERVERPROPERTY('productversion') as varchar), '')
	+'~'+ Coalesce(CAST(SERVERPROPERTY('ProductLevel') as varchar), '')
	+'~'+ Coalesce(CAST(SERVERPROPERTY('Edition') as varchar), '')
	+'~'+ Coalesce(CAST(SERVERPROPERTY('Collation') as varchar), '')
	+'~'+ Coalesce(CAST(SERVERPROPERTY('IsClustered') as varchar), '')
	+'~'+ Coalesce(CAST(SERVERPROPERTY('IsFullTextInstalled') as varchar), '')
	+'~'+ Coalesce(CAST(SERVERPROPERTY('IsIntegratedSecurityOnly') as varchar), '')
	+'~'+ Coalesce(CAST(SERVERPROPERTY('LicenseType') as varchar), '')
	+'~'+ Coalesce(CAST(SERVERPROPERTY('NumLicenses') as varchar), '');

print char(13)+char(10);

select /* my SchemasStatistics query */
	SDB.name
	+ '~' + SF.name
	+ '~' + (SELECT 'file_type' =  
			   CASE  
				   WHEN SF.groupid <> 0 THEN 'data'
				   WHEN SF.groupid = 0 THEN 'log'
			 END)
	+ '~' + SF.filename
	+ '~' + CAST((CAST(v.low as float) * SF.size)/(1024*1024) as varchar)
	AS "db_name~logical_file_name~file_type~physical_file_name~Size (MB)~@end"
FROM master.dbo.sysaltfiles SF inner join master.dbo.sysdatabases SDB on (SF.dbid = SDB.dbid),
	master.dbo.spt_values v
WHERE v.number=1 and v.type='E'
ORDER by SDB.name, SF.filename;

print char(13)+char(10);

DECLARE     @Drives TABLE
      (
            drive VARCHAR(5),
            [MB free] int,
            rownum smallint identity
      );

INSERT INTO @Drives EXEC xp_fixeddrives;     
print 'drive~Free(MB)~@end';
SELECT (drive + '~' + CAST([MB free] as varchar))
FROM  @Drives;

print char(13)+char(10);

print 'database_id~session_id~wait_duration_ms~wait_type~wait_resource~blocking_session_id~login_name~status~cpu_time~memory_usage~total_scheduled_time~total_elapsed_time~reads~writes~logical_reads~open_transaction_count~program_name~command~last_wait_type~@end';
select /* my SchemasStatistics query */
	Coalesce(CAST(DB_NAME(dm_r.database_id) as varchar),'') +'~'+  
	Coalesce(CAST(dm_wt.session_id as varchar),'') +'~'+ 
	Coalesce(CAST(dm_wt.wait_duration_ms as varchar),'') +'~'+
	Coalesce(CAST(dm_wt.wait_type as varchar),'') +'~' +
	Coalesce(CAST(dm_r.wait_resource as varchar),'') +'~' +
	Coalesce(CAST(dm_wt.blocking_session_id as varchar),'') +'~' +
	Coalesce(CAST(dm_es.login_name as varchar),'') +'~'+
	Coalesce(CAST(dm_es.status as varchar),'') +'~'+
	Coalesce(CAST(dm_es.cpu_time as varchar),'') +'~'+
	Coalesce(CAST(dm_es.memory_usage as varchar),'') +'~'+  
	Coalesce(CAST(dm_es.total_scheduled_time as varchar),'') +'~'+  
	Coalesce(CAST(dm_es.total_elapsed_time as varchar),'') +'~'+  
	Coalesce(CAST(dm_es.reads as varchar),'') +'~'+  
	Coalesce(CAST(dm_es.writes as varchar),'') +'~'+  
	Coalesce(CAST(dm_es.logical_reads as varchar),'') +'~'+  
	Coalesce(CAST(dm_r.open_transaction_count as varchar),'') +'~'+ 
	Coalesce(CAST(dm_es.program_name as varchar),'') +'~'+ 
	Coalesce(CAST(dm_r.command as varchar),'') +'~'+ 
	Coalesce(CAST(dm_r.last_wait_type as varchar),'')
from sys.dm_os_waiting_tasks dm_wt
	INNER JOIN sys.dm_exec_sessions dm_es ON dm_es.session_id = dm_wt.session_id
	INNER JOIN sys.dm_exec_requests dm_r ON dm_wt.session_id = dm_r.session_id
where dm_es.context_info<>0x000000000000000000000001
order by dm_r.database_id, dm_wt.wait_duration_ms;

print char(13)+char(10);

print 'Session ID~User Process~Login~Database~Task State~Command~Application~Wait Time (ms)~Wait Type~Wait Resource~Blocked By~Head Blocker~Head Blocker' + 
      '~Total Physical I/O (MB)~Total Physical Reads (MB)~Total Physical Writes (MB)~Total Logical I/O (MB)~Memory Use (KB)~Open Transactions~Login Time' + 
      '~Last Request Start Time~Host Name~Net Address~Execution Context ID~Request ID~Workload Group' + 
      '~p.waittime~p.cmd~p.status~p.lastwaittype~p.hostname(app server)~p.open_tran~dm_t.TEXT~@end'

select /* my SchemasStatistics query */
   Coalesce(CAST(s.session_id as varchar),'') +'~'+  
   Coalesce(CAST(CONVERT(CHAR(1), s.is_user_process) as varchar),'') +'~'+ 
   Coalesce(CAST(s.login_name as varchar),'') +'~'+ 
   Coalesce(CAST(ISNULL(db_name(p.dbid), N'') as varchar),'') +'~'+ 
   Coalesce(CAST(ISNULL(t.task_state, N'') as varchar),'') +'~'+ 
   Coalesce(CAST(ISNULL(r.command, N'') as varchar),'') +'~'+ 
   Coalesce(CAST(ISNULL(s.program_name, N'') as varchar),'') +'~'+ 
   Coalesce(CAST(ISNULL(w.wait_duration_ms, 0) as varchar),'') +'~'+ 
   Coalesce(CAST(ISNULL(w.wait_type, N'') as varchar),'') +'~'+ 
   Coalesce(CAST(ISNULL(w.resource_description, N'') as varchar),'') +'~'+ 
   Coalesce(CAST(ISNULL(CONVERT (varchar, w.blocking_session_id), '') as varchar),'') +'~'+ 
   Coalesce(CAST(
        CASE 
            -- session has an active request, is blocked, but is blocking others or session is idle but has an open tran and is blocking others
            WHEN r2.session_id IS NOT NULL AND (r.blocking_session_id = 0 OR r.session_id IS NULL) THEN '1' 
            -- session is either not blocking someone, or is blocking someone but is blocked by another party
            ELSE ''
        END as varchar),'') +'~'+ 
   Coalesce(CAST(s.cpu_time as varchar),'') +'~'+ 
   Coalesce(CAST((s.reads + s.writes) * 8 / 1024 as varchar),'') +'~'+ 
   Coalesce(CAST(s.reads*8/1024 as varchar),'') +'~'+ 
   Coalesce(CAST(s.writes*8/1024 as varchar),'') +'~'+ 
   Coalesce(CAST(s.logical_reads*8/1024 as varchar),'') +'~'+ 
   Coalesce(CAST(s.memory_usage * 8192 / 1024 as varchar),'') +'~'+ 
   Coalesce(CAST(ISNULL(r.open_transaction_count,0) as varchar),'') +'~'+ 
   Coalesce(CAST(s.login_time as varchar),'') +'~'+ 
   Coalesce(CAST(s.last_request_start_time as varchar),'') +'~'+ 
   Coalesce(CAST(ISNULL(s.host_name, N'') as varchar),'') +'~'+ 
   Coalesce(CAST(ISNULL(c.client_net_address, N'') as varchar),'') +'~'+ 
   Coalesce(CAST(ISNULL(t.exec_context_id, 0) as varchar),'') +'~'+ 
   Coalesce(CAST(ISNULL(r.request_id, 0) as varchar),'') +'~'+ 
   Coalesce(CAST(ISNULL(g.name, N'') as varchar),'') +'~'+ 
   --,p.*,
   Coalesce(CAST(p.waittime as varchar),'') +'~'+ 
   Coalesce(CAST(p.cmd as varchar),'') +'~'+ 
   Coalesce(CAST(p.status as varchar),'') +'~'+ 
   Coalesce(CAST(p.lastwaittype as varchar),'') +'~'+ 
   Coalesce(CAST(p.hostname as varchar),'') +'~'+ 
   Coalesce(CAST(p.open_tran as varchar),'') +'~'+ 
   Coalesce(CAST(dm_t.TEXT as varchar),'')
FROM sys.dm_exec_sessions s 
	LEFT OUTER JOIN sys.dm_exec_connections c ON (s.session_id = c.session_id)
	LEFT OUTER JOIN sys.dm_exec_requests r ON (s.session_id = r.session_id)
	LEFT OUTER JOIN sys.dm_os_tasks t ON (r.session_id = t.session_id AND r.request_id = t.request_id)
	LEFT OUTER JOIN 
	(
		-- In some cases (e.g. parallel queries, also waiting for a worker), one thread can be flagged as 
		-- waiting for several different threads.  This will cause that thread to show up in multiple rows 
		-- in our grid, which we don't want.  Use ROW_NUMBER to select the longest wait for each thread, 
		-- and use it as representative of the other wait relationships this thread is involved in. 
		SELECT *, ROW_NUMBER() OVER (PARTITION BY waiting_task_address ORDER BY wait_duration_ms DESC) AS row_num
		FROM sys.dm_os_waiting_tasks 
	) w ON (t.task_address = w.waiting_task_address) AND w.row_num = 1
	LEFT OUTER JOIN sys.dm_exec_requests r2 ON (s.session_id = r2.blocking_session_id)
	LEFT OUTER JOIN sys.dm_resource_governor_workload_groups g ON (g.group_id = s.group_id)
	LEFT OUTER JOIN sys.sysprocesses p ON (s.session_id = p.spid)
	OUTER APPLY sys.dm_exec_sql_text (p.sql_handle) dm_t
where s.context_info<>0x000000000000000000000001
ORDER BY p.dbid,s.session_id;

print char(13)+char(10);

print 'total_physical_memory_kb~available_physical_memory_kb~total_page_file_kb~available_page_file_kb~system_cache_kb~kernel_paged_pool_kb~kernel_nonpaged_pool_kb~system_high_memory_signal_state~system_low_memory_signal_state~system_memory_state_desc~@end';
select /* my SchemasStatistics query */
	Coalesce(CAST(total_physical_memory_kb as varchar),'') +'~'+ 
	Coalesce(CAST(available_physical_memory_kb as varchar),'') +'~'+ 
	Coalesce(CAST(total_page_file_kb as varchar),'') +'~'+ 
	Coalesce(CAST(available_page_file_kb as varchar),'') +'~'+ 
	Coalesce(CAST(system_cache_kb as varchar),'') +'~'+ 
	Coalesce(CAST(kernel_paged_pool_kb as varchar),'') +'~'+ 
	Coalesce(CAST(kernel_nonpaged_pool_kb as varchar),'') +'~'+ 
	Coalesce(CAST(system_high_memory_signal_state as varchar),'') +'~'+ 
	Coalesce(CAST(system_low_memory_signal_state as varchar),'') +'~'+ 
	Coalesce(CAST(system_memory_state_desc as varchar),'')
from sys.dm_os_sys_memory;

print char(13)+char(10);

print 'physical_memory_in_use_kb~large_page_allocations_kb~locked_page_allocations_kb~total_virtual_address_space_kb~virtual_address_space_reserved_kb~virtual_address_space_committed_kb~virtual_address_space_available_kb~page_fault_count~memory_utilization_percentage~available_commit_limit_kb~process_physical_memory_low~process_virtual_memory_low~@end';
select /* my SchemasStatistics query */
	Coalesce(CAST(physical_memory_in_use_kb as varchar),'') +'~'+ 
	Coalesce(CAST(large_page_allocations_kb as varchar),'') +'~'+ 
	Coalesce(CAST(locked_page_allocations_kb as varchar),'') +'~'+ 
	Coalesce(CAST(total_virtual_address_space_kb as varchar),'') +'~'+ 
	Coalesce(CAST(virtual_address_space_reserved_kb as varchar),'') +'~'+ 
	Coalesce(CAST(virtual_address_space_committed_kb as varchar),'') +'~'+ 
	Coalesce(CAST(virtual_address_space_available_kb as varchar),'') +'~'+ 
	Coalesce(CAST(page_fault_count as varchar),'') +'~'+ 
	Coalesce(CAST(memory_utilization_percentage as varchar),'') +'~'+ 
	Coalesce(CAST(available_commit_limit_kb as varchar),'') +'~'+ 
	Coalesce(CAST(process_physical_memory_low as varchar),'') +'~'+ 
	Coalesce(CAST(process_virtual_memory_low as varchar),'')
from sys.dm_os_process_memory;

print char(13)+char(10);

print 'cpu_ticks~ms_ticks~cpu_count~hyperthread_ratio~stack_size_in_bytes~os_quantum~os_error_mode~os_priority_class~max_workers_count~scheduler_count~scheduler_total_count~deadlock_monitor_serial_number~sqlserver_start_time_ms_ticks~sqlserver_start_time~@end';
select 
	Coalesce(CAST(cpu_ticks as varchar),'') +'~'+ 
	Coalesce(CAST(ms_ticks as varchar),'') +'~'+ 
	Coalesce(CAST(cpu_count as varchar),'') +'~'+ 
	Coalesce(CAST(hyperthread_ratio as varchar),'') +'~'+ 
	Coalesce(CAST(stack_size_in_bytes as varchar),'') +'~'+ 
	Coalesce(CAST(os_quantum as varchar),'') +'~'+ 
	Coalesce(CAST(os_error_mode as varchar),'') +'~'+ 
	Coalesce(CAST(os_priority_class as varchar),'') +'~'+ 
	Coalesce(CAST(max_workers_count as varchar),'') +'~'+ 
	Coalesce(CAST(scheduler_count as varchar),'') +'~'+ 
	Coalesce(CAST(scheduler_total_count as varchar),'') +'~'+ 
	Coalesce(CAST(deadlock_monitor_serial_number as varchar),'') +'~'+ 
	Coalesce(CAST(sqlserver_start_time_ms_ticks as varchar),'') +'~'+ 
	Coalesce(CAST(sqlserver_start_time as varchar),'')
from sys.dm_os_sys_info;

print char(13)+char(10);

print 'name~database_id~source_database_id~owner_sid~create_date~compatibility_level~collation_name~user_access~user_access_desc~is_read_only~is_auto_close_on~is_auto_shrink_on~state~state_desc~is_in_standby~is_cleanly_shutdown~is_supplemental_logging_enabled~snapshot_isolation_state~snapshot_isolation_state_desc~is_read_committed_snapshot_on~recovery_model~recovery_model_desc~page_verify_option~page_verify_option_desc~is_auto_create_stats_on~is_auto_update_stats_on~is_auto_update_stats_async_on~is_broker_enabled~log_reuse_wait~log_reuse_wait_desc~is_encrypted~@end';
select /* my SchemasStatistics query */
	Coalesce(CAST(name as varchar), '') COLLATE DATABASE_DEFAULT
	+ '~' + Coalesce(CAST(database_id as varchar), '')
	+ '~' + Coalesce(CAST(source_database_id as varchar), '')
	+ '~' + Coalesce(CAST(master.dbo.fn_varbintohexstr(owner_sid) as varchar), '')
	+ '~' + Coalesce(CAST(create_date as varchar), '')
	+ '~' + Coalesce(CAST(compatibility_level as varchar), '')
	+ '~' + Coalesce(CAST(collation_name as varchar), '') COLLATE DATABASE_DEFAULT
	+ '~' + Coalesce(CAST(user_access as varchar), '')
	+ '~' + Coalesce(CAST(user_access_desc as varchar), '')
	+ '~' + Coalesce(CAST(is_read_only as varchar), '')
	+ '~' + Coalesce(CAST(is_auto_close_on as varchar), '')
	+ '~' + Coalesce(CAST(is_auto_shrink_on as varchar), '')
	+ '~' + Coalesce(CAST(state as varchar), '')
	+ '~' + Coalesce(CAST(state_desc as varchar), '')
	+ '~' + Coalesce(CAST(is_in_standby as varchar), '')
	+ '~' + Coalesce(CAST(is_cleanly_shutdown as varchar), '')
	+ '~' + Coalesce(CAST(is_supplemental_logging_enabled as varchar), '')
	+ '~' + Coalesce(CAST(snapshot_isolation_state as varchar), '')
	+ '~' + Coalesce(CAST(snapshot_isolation_state_desc as varchar), '')
	+ '~' + Coalesce(CAST(is_read_committed_snapshot_on as varchar), '')
	+ '~' + Coalesce(CAST(recovery_model as varchar), '')
	+ '~' + Coalesce(CAST(recovery_model_desc as varchar), '')
	+ '~' + Coalesce(CAST(page_verify_option as varchar), '')
	+ '~' + Coalesce(CAST(page_verify_option_desc as varchar), '')
	+ '~' + Coalesce(CAST(is_auto_create_stats_on as varchar), '')
	+ '~' + Coalesce(CAST(is_auto_update_stats_on as varchar), '')
	+ '~' + Coalesce(CAST(is_auto_update_stats_async_on as varchar), '')
	+ '~' + Coalesce(CAST(is_broker_enabled as varchar), '')
	+ '~' + Coalesce(CAST(log_reuse_wait as varchar), '')
	+ '~' + Coalesce(CAST(log_reuse_wait_desc as varchar), '')
	+ '~' + Coalesce(CAST(is_encrypted as varchar), '')
from master.sys.databases 
where name in ('master','tempdb','model','msdb','$(cmdb_dbname)');

print char(13)+char(10);

print 'object_name~counter_name~instance_name~cntr_value~cntr_type~@end';
select /* my SchemasStatistics query */
	ltrim(rtrim(Coalesce(CAST(object_name as varchar),''))) +'~'+ 
	ltrim(rtrim(Coalesce(CAST(counter_name as varchar),''))) +'~'+ 
	ltrim(rtrim(Coalesce(CAST(instance_name as varchar),''))) +'~'+ 
	ltrim(rtrim(Coalesce(CAST(cntr_value as varchar),''))) +'~'+ 
	ltrim(rtrim(Coalesce(CAST(cntr_type as varchar),'')))
from sys.dm_os_performance_counters 
order by object_name;

print char(13)+char(10);

print 'DBName~dbid~AvgTRT_ms~CNT~TotalTime_ms~AVG_CPU_MS~AVG_LOGICAL_READS~AVG_PHYSICAL_READS~AVG_LOGICAL_WRITES~AVG_ELAPSED_TIME~' + 
	'plan_generation_num~creation_time~last_execution_time~' + 
	'total_worker_time~last_worker_time~min_worker_time~max_worker_time~' + 
	'total_physical_reads~last_physical_reads~min_physical_reads~max_physical_reads~' + 
	'total_logical_writes~last_logical_writes~min_logical_writes~max_logical_writes~' + 
	'total_logical_reads~last_logical_reads~min_logical_reads~max_logical_reads~' + 
	'total_elapsed_time~last_elapsed_time~min_elapsed_time~max_elapsed_time~text~statement_text~@end'
select /* my SchemasStatistics query */
	DB_NAME(CAST(PA.value as int)) +'~'+ CAST(CAST(PA.value as int) as varchar) +'~'+  
	CAST(QS.total_elapsed_time/execution_count/1000  as varchar) +'~'+ 
	CAST(QS.execution_count  as varchar) +'~'+ CAST(QS.total_elapsed_time/1000 as varchar) +'~'+ 
        SUBSTRING(CONVERT(CHAR(23),
                  DATEADD(ms,(total_worker_time/execution_count)/1000,0),
                          121),
                  12,23) +'~'+ 
	CAST(total_logical_reads/execution_count as varchar) +'~'+ 
	CAST(total_physical_reads/execution_count as varchar) +'~'+ 
	CAST(total_logical_writes/execution_count as varchar) +'~'+ 
	SUBSTRING(CONVERT(CHAR(23),
                  DATEADD(ms,(total_elapsed_time/execution_count)/1000,0),
                          121),
                  12,23) +'~'+ 
	CAST(plan_generation_num as varchar) +'~'+ CAST(creation_time as varchar) +'~'+ CAST(last_execution_time as varchar) +'~'+ 
	CAST(total_worker_time as varchar) +'~'+ CAST(last_worker_time as varchar) +'~'+ CAST(min_worker_time as varchar) +'~'+ CAST(max_worker_time as varchar) +'~'+ 
	CAST(total_physical_reads as varchar) +'~'+ CAST(last_physical_reads as varchar) +'~'+ CAST(min_physical_reads as varchar) +'~'+ CAST(max_physical_reads as varchar) +'~'+ 
	CAST(total_logical_writes as varchar) +'~'+ CAST(last_logical_writes as varchar) +'~'+ CAST(min_logical_writes as varchar) +'~'+ CAST(max_logical_writes as varchar) +'~'+ 
	CAST(total_logical_reads as varchar) +'~'+ CAST(last_logical_reads as varchar) +'~'+ CAST(min_logical_reads as varchar) +'~'+ CAST(max_logical_reads as varchar) +'~'+ 
	CAST(total_elapsed_time as varchar) +'~'+ CAST(last_elapsed_time as varchar) +'~'+ CAST(min_elapsed_time as varchar) +'~'+ CAST(max_elapsed_time as varchar) +'~'+ 
	REPLACE(REPLACE(REPLACE(text, CHAR(10), '\n'), CHAR(13), '\r'), CHAR(9), '\t') +'~'+  
	REPLACE(REPLACE(REPLACE(
		SUBSTRING(SUBSTRING(st.text, (qs.statement_start_offset/2) + 1,
	         ((CASE statement_End_offset
	          WHEN -1 THEN DATALENGTH(st.text)
	          ELSE qs.statement_End_offset End
	            - qs.statement_start_offset)/2) + 1),1,4000), CHAR(10), '\n'), CHAR(13), '\r'), CHAR(9), '\t')
	--, QS.*, ST.*, PA.*
from sys.dm_exec_query_stats QS 
	CROSS APPLY sys.dm_exec_sql_text (sql_handle) ST
	OUTER APPLY sys.dm_exec_plan_attributes(plan_handle) PA 
where attribute='dbid' and text not like '%select /* my SchemasStatistics query */%'
order by QS.total_elapsed_time/execution_count/1000 desc, QS.total_elapsed_time desc;
-------------------------------------

print char(13)+char(10);
print 'System Configuration'
print 'configuration_id~name~value~minimum~maximum~value_in_use~description~is_dynamic~is_advanced~@end';
select 
  Coalesce(CAST(configuration_id as varchar) , '')
  + '~' + Coalesce(CAST(name as varchar(100)), '') COLLATE DATABASE_DEFAULT
  + '~' + Coalesce(CAST(value as varchar), '')
  + '~' + Coalesce(CAST(minimum as varchar), '')
  + '~' + Coalesce(CAST(maximum as varchar), '')
  + '~' + Coalesce(CAST(value_in_use as varchar), '')
  + '~' + Coalesce(cast(description as varchar(500)), '') COLLATE DATABASE_DEFAULT
  + '~' + Coalesce(CAST(is_dynamic as varchar), '')  
  + '~' + Coalesce(CAST(is_advanced as varchar), '')  
from sys.configurations

print char(13)+char(10);
print 'tempdb files information'
print char(13)+char(10);
print 'file_id~file_guid~type~type_desc~data_space_id~name~physical_name~state~state_desc~size~max_size~growth_MB~is_percent_growth~is_media_read_only~is_read_only~is_sparse~create_lsn~@end';
select 
  Coalesce(CAST(file_id as varchar) , '')
  + '~' + Coalesce(CAST(file_guid as varchar(50)), '') COLLATE DATABASE_DEFAULT
  + '~' + Coalesce(CAST(type as varchar), '')
  + '~' + Coalesce(type_desc, '')
  + '~' + Coalesce(CAST(data_space_id as varchar), '')  
  + '~' + Coalesce(cast(name as varchar(200)), '') COLLATE DATABASE_DEFAULT
  + '~' + Coalesce(physical_name, '')
  + '~' + Coalesce(CAST(state as varchar), '') 
  + '~' + Coalesce(state_desc, '')
  + '~' + Coalesce(CAST(size as varchar), '') 
  + '~' + Coalesce(CAST(max_size as varchar), '') 
  + '~' + Coalesce(CAST(
		case when is_percent_growth = 0 then growth * 8 / 1024.0 
		else growth end as varchar), '')
  + '~' + Coalesce(CAST(is_percent_growth as varchar), '')
  + '~' + Coalesce(CAST(is_media_read_only as varchar), '')
  + '~' + Coalesce(CAST(is_read_only as varchar), '')
  + '~' + Coalesce(CAST(is_sparse as varchar),'') 
  + '~' + Coalesce(CAST(create_lsn as varchar), '')
from tempdb.sys.database_files

---------------------------
use $(cmdb_dbname)

print 'database files information'
print char(13)+char(10);
print 'file_id~file_guid~type~type_desc~data_space_id~name~physical_name~state~state_desc~size~max_size~growth_MB~is_percent_growth~is_media_read_only~is_read_only~is_sparse~create_lsn~@end';
select 
  Coalesce(CAST(file_id as varchar) , '')
  + '~' + Coalesce(CAST(file_guid as varchar(50)), '') COLLATE DATABASE_DEFAULT
  + '~' + Coalesce(CAST(type as varchar), '')
  + '~' + Coalesce(type_desc, '')
  + '~' + Coalesce(CAST(data_space_id as varchar), '')  
  + '~' + Coalesce(cast(name as varchar(200)), '') COLLATE DATABASE_DEFAULT
  + '~' + Coalesce(physical_name, '')
  + '~' + Coalesce(CAST(state as varchar), '') 
  + '~' + Coalesce(state_desc, '')
  + '~' + Coalesce(CAST(size as varchar), '') 
  + '~' + Coalesce(CAST(max_size as varchar), '') 
  + '~' + Coalesce(CAST(
		case when is_percent_growth = 0 then growth * 8 / 1024.0 
		else growth end as varchar), '')
  + '~' + Coalesce(CAST(is_percent_growth as varchar), '')
  + '~' + Coalesce(CAST(is_media_read_only as varchar), '')
  + '~' + Coalesce(CAST(is_read_only as varchar), '')
  + '~' + Coalesce(CAST(is_sparse as varchar),'') 
  + '~' + Coalesce(CAST(create_lsn as varchar), '')
from sys.database_files


print char(13)+char(10);

print 'TblName~object_id~index_id~IndexName~PercentFragment~TotalFrags~PagesPerFrag~NumPages~IndexType~index_depth~index_level~avg_page_space_used_in_percent~record_count~ghost_record_count~version_ghost_record_count~min_record_size_in_bytes~max_record_size_in_bytes~avg_record_size_in_bytes~forwarded_record_count~compressed_page_count~@end';
select /* my SchemasStatistics query */
	OBJECT_NAME(b.object_id)
	+ '~' + CAST(a.object_id as varchar)
	+ '~' + CAST(a.index_id as varchar)
	+ '~' + Coalesce(b.name,'')
	+ '~' + CAST(Coalesce(a.avg_fragmentation_in_percent,'') as varchar)
	+ '~' + CAST(CAST(Coalesce(a.fragment_count,'') as bigint) as varchar)
	+ '~' + CAST(Coalesce(a.avg_fragment_size_in_pages,'') as varchar)
	+ '~' + CAST(CAST(Coalesce(a.page_count,'') as bigint) as varchar)
	+ '~' + Coalesce(a.index_type_desc,'')
	+ '~' + CAST(Coalesce(a.index_depth,'') as varchar)
	+ '~' + CAST(Coalesce(a.index_level,'') as varchar)
	+ '~' + CAST(Coalesce(a.avg_page_space_used_in_percent,'') as varchar)
	+ '~' + CAST(CAST(Coalesce(a.record_count,'') as bigint) as varchar)
	+ '~' + CAST(CAST(Coalesce(a.ghost_record_count,'') as bigint) as varchar)
	+ '~' + CAST(CAST(Coalesce(a.version_ghost_record_count,'') as bigint) as varchar)
	+ '~' + CAST(Coalesce(a.min_record_size_in_bytes,'') as varchar)
	+ '~' + CAST(Coalesce(a.max_record_size_in_bytes,'') as varchar)
	+ '~' + CAST(Coalesce(a.avg_record_size_in_bytes,'') as varchar)
	+ '~' + CAST(CAST(Coalesce(a.forwarded_record_count,'') as bigint) as varchar)
	+ '~' + CAST(CAST(Coalesce(a.compressed_page_count,'') as bigint) as varchar)
FROM sys.dm_db_index_physical_stats(DB_ID('$(cmdb_dbname)'),NULL, NULL, NULL , 'SAMPLED') AS a
			JOIN sys.indexes AS b
				ON a.object_id = b.object_id AND a.index_id = b.index_id
--WHERE a.avg_fragmentation_in_percent > 0
ORDER BY OBJECT_NAME(b.object_id),a.index_id;

print char(13)+char(10);

print 'schema_name~table_name~index_name~Allocated (in M)~Used (in M)~Unused (in M)~Row Count (approx.)~in_row_data_page_count~in_row_used_page_count~in_row_reserved_page_count~lob_used_page_count~lob_reserved_page_count~row_overflow_used_page_count~row_overflow_reserved_page_count~used_page_count~reserved_page_count~row_count~used(MB)~reserved(MB)~tbl_rows~@end';
select /* my SchemasStatistics query */
	s.Name
	+ '~' + o.Name
	+ '~' + coalesce(i.Name, 'HEAP')
	+ '~' + CAST(CAST(CAST(si.reserved AS DECIMAL(10,1))* 8 / 1024.0 AS DECIMAL(10,1)) as varchar)
	+ '~' + CAST(CAST(CAST(si.dpages AS DECIMAL(10,1)) * 8 / 1024.0 AS DECIMAL(10,1)) as varchar)
	+ '~' + CAST(CAST(CAST((si.reserved - si.dpages) AS DECIMAL(10,1)) * 8 / 1024.0 AS DECIMAL(10,1)) as varchar)
	+ '~' + CAST(rowcnt as varchar)
	+ '~' + CAST(in_row_data_page_count as varchar)
	+ '~' + CAST(in_row_used_page_count as varchar)
	+ '~' + CAST(in_row_reserved_page_count as varchar)
	+ '~' + CAST(lob_used_page_count as varchar)
	+ '~' + CAST(lob_reserved_page_count as varchar)
	+ '~' + CAST(row_overflow_used_page_count as varchar)
	+ '~' + CAST(row_overflow_reserved_page_count as varchar)
	+ '~' + CAST(used_page_count as varchar)
	+ '~' + CAST(reserved_page_count as varchar)
	+ '~' + CAST(row_count as varchar)
	+ '~' + CAST(CAST(CAST(p.used_page_count AS DECIMAL(10,1)) * 8 / 1024.0 AS DECIMAL(10,1)) as varchar)
	+ '~' + CAST(CAST(CAST(p.reserved_page_count AS DECIMAL(10,1)) * 8 / 1024.0 AS DECIMAL(10,1)) as varchar)
	+ '~' + case when i.index_id in ( 0, 1 ) then CAST(p.row_count as varchar) else '0' end
	 --, case when i.index_id in ( 0, 1 ) then p.row_count else 0 end "tbl_rows"
FROM sys.dm_db_partition_stats p
	INNER JOIN sys.objects as o
		ON o.object_id = p.object_id
	INNER JOIN sys.schemas as s
		ON s.schema_id = o.schema_id
	LEFT OUTER JOIN sys.indexes as i
		on (i.object_id = p.object_id and i.index_id = p.index_id)
	INNER JOIN sys.sysindexes as si on (i.object_id = si.id and i.index_id = si.indid)
WHERE o.type_desc = 'USER_TABLE'
		and o.is_ms_shipped = 0
order by s.Name,o.Name,si.indid;

print char(13)+char(10);

select /* my SchemasStatistics query */
	SCHEMA_NAME(tbl.schema_id)
	+ '~' + tbl.Name
	+ '~' + CAST(tbl.max_column_id_used as varchar)
	+ '~' + CAST(CASE idx.index_id WHEN 1 THEN 1 ELSE 0 END AS varchar)
	+ '~' + CAST(CAST(Coalesce( (Select sum (spart.rows) from sys.partitions spart 
				Where spart.object_id = tbl.object_id and spart.index_id < 2), 0) as bigint) as varchar)
	+ '~' + CAST(CAST(Coalesce( (Select Cast(v.low/1024.0 as float) 
				* SUM(a.used_pages - CASE WHEN a.type <> 1 THEN a.used_pages WHEN p.index_id < 2 THEN a.data_pages ELSE 0 END) 
					FROM sys.indexes as i
					 JOIN sys.partitions as p ON p.object_id = i.object_id and p.index_id = i.index_id
					 JOIN sys.allocation_units as a ON a.container_id = p.partition_id
					Where i.object_id = tbl.object_id  )
				, 0.0) as bigint) as varchar)
	+ '~' + CAST(CAST(Coalesce( (Select Cast(v.low/1024.0 as float)
				* SUM(CASE WHEN a.type <> 1 THEN a.used_pages WHEN p.index_id < 2 THEN a.data_pages ELSE 0 END) 
					FROM sys.indexes as i
					 JOIN sys.partitions as p ON p.object_id = i.object_id and p.index_id = i.index_id
					 JOIN sys.allocation_units as a ON a.container_id = p.partition_id
					Where i.object_id = tbl.object_id)
				, 0.0) as bigint) as varchar)
	+ '~' + CONVERT(VARCHAR(25), tbl.create_date, 113)
	+ '~' + CAST(tbl.modify_date as varchar) as "Schema~TblName~Columns~HasClusIdx~RowCount~IndexKB~DataKB~create_date~modify_date~@end"
	FROM sys.tables AS tbl
	  INNER JOIN sys.indexes AS idx ON (idx.object_id = tbl.object_id and idx.index_id < 2)
	  INNER JOIN master.dbo.spt_values v ON (v.number=1 and v.type='E')
	ORDER BY SCHEMA_NAME(tbl.schema_id),tbl.Name;

print char(13)+char(10);

select /* my SchemasStatistics query */
	SDB.name
	+ '~' + SF.name
	+ '~' + (SELECT 'file_type' =  
			   CASE  
				   WHEN SF.groupid <> 0 THEN 'data'
				   WHEN SF.groupid = 0 THEN 'log'
			 END)
	+ '~' + SF.filename
	+ '~' + CAST((CAST(v.low as float) * SF.size)/(1024*1024) as varchar)
	AS "db_name~logical_file_name~file_type~physical_file_name~Size (MB)~@end"
FROM master.dbo.sysaltfiles SF inner join master.dbo.sysdatabases SDB on (SF.dbid = SDB.dbid),
	master.dbo.spt_values v
WHERE v.number=1 and v.type='E' and SDB.name='$(cmdb_dbname)'
ORDER by SDB.name, SF.filename;

print char(13)+char(10);

print 'TABLE_NAME~Count~@end';
	Exec('select /* my SchemasStatistics query */ ''CDM_ROOT_1'' + ''~'' + cast(count(*) as varchar) from CDM_ROOT_1');
	Exec('select /* my SchemasStatistics query */ ''HDM_ROOT_1'' + ''~'' + cast(count(*) as varchar) from HDM_ROOT_1');
	Exec('select /* my SchemasStatistics query */ ''MANAGED_OBJECT_1'' + ''~'' + cast(count(*) as varchar) from MANAGED_OBJECT_1');
	Exec('select /* my SchemasStatistics query */ ''MANAGED_RELATIONSHIP_1'' + ''~'' + cast(count(*) as varchar) from MANAGED_RELATIONSHIP_1');
	Exec('select /* my SchemasStatistics query */ ''NODE_1'' + ''~'' + cast(count(*) as varchar) from NODE_1');
	Exec('select /* my SchemasStatistics query */ ''CDM_NODE_1'' + ''~'' + cast(count(*) as varchar) from CDM_NODE_1');
	Exec('select /* my SchemasStatistics query */ ''IP_ADDRESS_1'' + ''~'' + cast(count(*) as varchar) from IP_ADDRESS_1');
	Exec('select /* my SchemasStatistics query */ ''CDM_IP_ADDRESS_1'' + ''~'' + cast(count(*) as varchar) from CDM_IP_ADDRESS_1');
	Exec('select /* my SchemasStatistics query */ ''HDM_140510IP_ADDRESS_1'' + ''~'' + cast(count(*) as varchar) from HDM_140510IP_ADDRESS_1');
	Exec('select /* my SchemasStatistics query */ ''LOA'' + ''~'' + cast(count(*) as varchar) from LOA');
	Exec('select /* my SchemasStatistics query */ ''CDM_LIST_ATTR_PRIMITIVE_1'' + ''~'' + cast(count(*) as varchar) from CDM_LIST_ATTR_PRIMITIVE_1');
	Exec('select /* my SchemasStatistics query */ ''CDM_INSTALLED_SOFTWARE_1'' + ''~'' + cast(count(*) as varchar) from CDM_INSTALLED_SOFTWARE_1');
	Exec('select /* my SchemasStatistics query */ ''CCM_DISCOVERY_DESTS_RESULTS'' + ''~'' + cast(count(*) as varchar) from CCM_DISCOVERY_DESTS_RESULTS');
	Exec('select /* my SchemasStatistics query */ ''CCM_DISCOVERY_STATS'' + ''~'' + cast(count(*) as varchar) from CCM_DISCOVERY_STATS');
	Exec('select /* my SchemasStatistics query */ ''CCM_DISCOVERY_DEST_IPS'' + ''~'' + cast(count(*) as varchar) from CCM_DISCOVERY_DEST_IPS');
	Exec('select /* my SchemasStatistics query */ ''CCM_DISCOVERY_DESTS'' + ''~'' + cast(count(*) as varchar) from CCM_DISCOVERY_DESTS');
	Exec('select /* my SchemasStatistics query */ ''CCM_DISCOVERY_ERRORS'' + ''~'' + cast(count(*) as varchar) from CCM_DISCOVERY_ERRORS');
	Exec('select /* my SchemasStatistics query */ ''CDM_COMPOSITION_1'' + ''~'' + cast(count(*) as varchar) from CDM_COMPOSITION_1');
	Exec('select /* my SchemasStatistics query */ ''HDM_140510COMPOSITION_1'' + ''~'' + cast(count(*) as varchar) from HDM_140510COMPOSITION_1');
	Exec('select /* my SchemasStatistics query */ ''CDM_PROCESS_1'' + ''~'' + cast(count(*) as varchar) from CDM_PROCESS_1');
	Exec('select /* my SchemasStatistics query */ ''HDM_141110PROCESS_1'' + ''~'' + cast(count(*) as varchar) from HDM_141110PROCESS_1');
	Exec('select /* my SchemasStatistics query */ ''CDM_WINDOWS_SERVICE_1'' + ''~'' + cast(count(*) as varchar) from CDM_WINDOWS_SERVICE_1');
	Exec('select /* my SchemasStatistics query */ ''HDML_141110WINDOWS_SERVICE_1'' + ''~'' + cast(count(*) as varchar) from HDML_141110WINDOWS_SERVICE_1');
	Exec('select /* my SchemasStatistics query */ ''CDM_MEMBERSHIP_1'' + ''~'' + cast(count(*) as varchar) from CDM_MEMBERSHIP_1');
	Exec('select /* my SchemasStatistics query */ ''HDM_141110MEMBERSHIP_1'' + ''~'' + cast(count(*) as varchar) from HDM_141110MEMBERSHIP_1');
	Exec('select /* my SchemasStatistics query */ ''CDM_CONTAINMENT_1'' + ''~'' + cast(count(*) as varchar) from CDM_CONTAINMENT_1');
	Exec('select /* my SchemasStatistics query */ ''HDM_141110CONTAINMENT_1'' + ''~'' + cast(count(*) as varchar) from HDM_141110CONTAINMENT_1');
	Exec('select /* my SchemasStatistics query */ ''CDM_CPU_1'' + ''~'' + cast(count(*) as varchar) from CDM_CPU_1');
	Exec('select /* my SchemasStatistics query */ ''HDM_141110CPU_1'' + ''~'' + cast(count(*) as varchar) from HDM_141110CPU_1');
	Exec('select /* my SchemasStatistics query */ ''CDM_ORACLE_1'' + ''~'' + cast(count(*) as varchar) from CDM_ORACLE_1');
	Exec('select /* my SchemasStatistics query */ ''HDM_141110ORACLE_1'' + ''~'' + cast(count(*) as varchar) from HDM_141110ORACLE_1');
	Exec('select /* my SchemasStatistics query */ ''CDM_INTERFACE_1'' + ''~'' + cast(count(*) as varchar) from CDM_INTERFACE_1');	
	Exec('select /* my SchemasStatistics query */ ''HDM_141110INTERFACE_1'' + ''~'' + cast(count(*) as varchar) from HDM_141110INTERFACE_1');
	Exec('select /* my SchemasStatistics query */ ''CDM_CLIENT_SERVER_1'' + ''~'' + cast(count(*) as varchar) from CDM_CLIENT_SERVER_1');	
	Exec('select /* my SchemasStatistics query */ ''HDM_141110CLIENT_SERVER_1'' + ''~'' + cast(count(*) as varchar) from HDM_141110CLIENT_SERVER_1');
	Exec('select /* my SchemasStatistics query */ ''CDM_REALIZATION_1'' + ''~'' + cast(count(*) as varchar) from CDM_REALIZATION_1');	
	Exec('select /* my SchemasStatistics query */ ''HDM_141110REALIZATION_1'' + ''~'' + cast(count(*) as varchar) from HDM_141110REALIZATION_1');
	Exec('select /* my SchemasStatistics query */ ''CDM_DEPENDENCY_1'' + ''~'' + cast(count(*) as varchar) from CDM_DEPENDENCY_1');	
	Exec('select /* my SchemasStatistics query */ ''HDM_141110DEPENDENCY_1'' + ''~'' + cast(count(*) as varchar) from HDM_141110DEPENDENCY_1');
	Exec('select /* my SchemasStatistics query */ ''CDM_USAGE_1'' + ''~'' + cast(count(*) as varchar) from CDM_USAGE_1');	
	Exec('select /* my SchemasStatistics query */ ''HDM_141110USAGE_1'' + ''~'' + cast(count(*) as varchar) from HDM_141110USAGE_1');
	Exec('select /* my SchemasStatistics query */ ''CDM_TRAFFIC_1'' + ''~'' + cast(count(*) as varchar) from CDM_TRAFFIC_1');	
	Exec('select /* my SchemasStatistics query */ ''HDM_141110TRAFFIC_1'' + ''~'' + cast(count(*) as varchar) from HDM_141110TRAFFIC_1');

print char(13)+char(10);

select /* my SchemasStatistics query */
	a_root_class + '~' + CAST(COUNT(*) As varchar)
	AS "a_root_class~Count~@end"
from CDM_ROOT_1 
group by a_root_class 
order by a_root_class;

